#
# spec file for package ltp
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
Name:           ltp
Version:        20200605.b54247721
Release:        368.1
Summary:        The Linux Test Project
License:        GPL-2.0-or-later
Group:          System/Benchmark
URL:            http://linux-test-project.github.io
Source:         %{name}-%{version}.tar.xz
Source1:        %{name}-rpmlintrc
Source99:       baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  libacl-devel
BuildRequires:  libaio-devel
BuildRequires:  libattr-devel
BuildRequires:  libcap-devel
BuildRequires:  libnuma-devel
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  pkgconfig
BuildRequires:  xfsprogs-devel
BuildRequires:  pkgconfig(libmnl)
BuildRequires:  pkgconfig(libtirpc)
BuildRequires:  pkgconfig(uuid)
Recommends:     acl
Recommends:     apparmor-parser
Recommends:     apparmor-utils
Recommends:     attr
Recommends:     audit
Recommends:     bc
Recommends:     binutils
Recommends:     dhcp-client
Recommends:     dhcp-server
Recommends:     diffutils
Recommends:     dnsmasq
Recommends:     dosfstools
Recommends:     ethtool
Recommends:     evmctl
Recommends:     fuse-exfat
Recommends:     gcc
Recommends:     gdb
Recommends:     iptables
Recommends:     iputils
Recommends:     kernel-default-extra
Recommends:     ltrace
Recommends:     lvm2
Recommends:     make
Recommends:     net-tools
Recommends:     net-tools-deprecated
Recommends:     nfs-client
Recommends:     nfs-kernel-server
Recommends:     ntfsprogs
Recommends:     numactl
Recommends:     psmisc
Recommends:     quota
Recommends:     rpcbind
Recommends:     rsync
Recommends:     sssd-tools
Recommends:     strace
Recommends:     sudo
Recommends:     sysstat
Recommends:     tcpdump
Recommends:     telnet
Recommends:     telnet-server
Recommends:     tpm-tools
Recommends:     vsftpd
Recommends:     wget
Recommends:     xfsprogs
Recommends:     xinetd
Conflicts:      ltp
%{perl_requires}

%description
A collection of test suites to validate the reliability, robustness and
stability of Linux. It provides tools for testing the kernel and
related features.

%prep
%setup -q

%build
make %{?_smp_mflags} autotools
%configure \
  --prefix=/opt/ltp \
  --with-realtime-testsuite \
  --with-open-posix-testsuite
make all %{?_smp_mflags}

%install
%make_install

# Deal with openposix test binaries and create runtest file
mkdir -p %{buildroot}/opt/ltp/testcases/bin/openposix

cd testcases/open_posix_testsuite
# Exclude tests which are "build only"
for i in `find conformance/interfaces/ -name '*.run-test' -a ! -name '*-buildonly*'` ; do
	# create runtest openposix file
	echo `basename "$i" .run-test | sed s/-/_/` '${LTPROOT}/testcases/bin/openposix/'$i >> ../../runtest/openposix;
	# install binaries
	mkdir -p %{buildroot}/opt/ltp/testcases/bin/openposix/`dirname $i`;
	cp $i %{buildroot}/opt/ltp/testcases/bin/openposix/`dirname $i`;
done
cp ../../runtest/openposix %{buildroot}/opt/ltp/runtest/
cd ../..

# Exclude tst_brkm
HARDLINKS1="tst_exit tst_fs_has_free tst_brk"
HARDLINKS2="tst_res tst_ncpus tst_ncpus_conf tst_ncpus_max tst_resm"
cd %{buildroot}/opt/ltp/testcases/bin
for n in $HARDLINKS1 $HARDLINKS2; do
	ln -s -f tst_brkm $n
done

%files
%license COPYING
%doc README.md INSTALL
/opt/ltp/
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_bindir}/execltp

%changelog
* Sun Jun  7 2020 pcervinka@suse.com
- Update to version 20200605.b54247721:
  * INSTALL: Mention rpcbind and portmap
  * syscalls/mknod07: whiteout creation no longer requires privileges
  * syscalls/ioctl_loop05: set loop blksize to bdev blksize
  * tst_taint.h Add taint for randstruct
  * acct02: fix the ac_version check on big endian platforms
  * lib/tst_test.c: Take account of tst_brk(TCONF/TFAIL) in summary output
  * ima: Always require TST_NEEDS_TMPDIR=1
  * ima: Fix tst_check_cmds usage
  * ima: style ${foo} => $foo
  * ima_policy.sh: Add missing TST_NEEDS_TMPDIR=1
* Wed May 27 2020 pvorel@suse.cz
- Recommends lvm2 (required by prepare_lvm.sh, added in 20200515).
* Thu May 21 2020 pvorel@suse.cz
- Add libmnl-devel (required for route netlik tests added in 20200515).
* Mon Mar 30 2020 pvorel@suse.cz
- Add dependencies: diffutils, telnet-server, xinetd (all for net.tcp_cmds)
* Wed Feb 26 2020 pvorel@suse.cz
- Add as Recommends: gcc, make (needed by nfs05) and nfs-client (nfsstat needed
  by nfsstat01).
* Sun Nov  3 2019 petr@cervinka.net
- Remove ffsb binary
* Thu Sep 19 2019 petr@cervinka.net
- Add recommends to baselibs.conf
* Thu Aug  1 2019 pvorel@suse.cz
- Update $HARDLINKS - remove tst_flush, tst_get_unused_port, tst_kvercmp,
  tst_kvercmp2. This reflect change in qa-testsuites
  https://github.com/SUSE/qa-testsuites/commit/471c531fff6060616b585a97b19f3f6d878dd8b9
  (poo#54932)
* Tue Jul 23 2019 pcervinka@suse.com
- Extend recommends by LTP runtime dependencies
* Fri Jul 19 2019 pcervinka@suse.com
- Remove rpmbuild from recommends
* Fri Jul 12 2019 pcervinka@suse.com
- Disable lto gcc flag
* Wed May 22 2019 pcervinka@suse.com
- Migrate to service file to get source from GitHub directly
- Rename rpmlintrc to ltp-rpmlintrc
- Run spec-cleaner
* Mon May 20 2019 mimi.vx@gmail.com
- update to 20190517
  * ioctl_ns{01-07}: Tests for NS_GET_* ioctls
  * clock_adjtim{01,02}: New tests
  * userfaultfd01: New test
  * ioctl08: Test for FIDEDUPERANGE on Btrfs
  * sigpending02: New test for sigpending/rt_sigpending
  * pivot_root01: New test
  * tgkill{01-03}: New tests
  * set_mempolicy{01-04}: New tests
  * rt_tgsigqueueinfo01: New test
  * binfmt_misc02.sh: New functionality test
  * pwritev2{01-02}: New tests
  * rt_sigpending02: New test
  * fanotify12: New test for FAN_OPEN_EXEC event mask
  * clock_gettime{01,02}: New tests
  * fdatasync03: New test
  * fsync04: New test
  * sync03: New test
  * syncfs01: New test
  * setrlimit06: Add new test for RLIMIT_CPU
  * statx07: Add test for AT_STATX_DONT_SYNC and AT_STATX_FORCE_SYNC
  * clock_settime{01,02}: New tests
  * af_alg06: malformed authenc key 8f9c46934848
  * af_alg05: skcipher_walk error bug 8088d3dd4d7c
  * af_alg04: vmac race conditions bb2964810233
  * af_alg03: rfc7539 hash alg validation e57121d08c38
  * af_alg02: salsa20 empty message bug ecaaab564978 aka CVE-2017-17805
  * af_alg01: hmac nesting bug af3ff8045bbf aka CVE-2017-17806
  * binfmt_misc01.sh: 5cc41e099504 ("fs/binfmt_misc.c: do not allow offset overflow)
  * fanotify01: add FAN_REPORT_FID test cases
  * fanotify10: increase test coverage to support FAN_OPEN_EXEC mask
  * fanotify03: add FAN_OPEN_EXEC_PERM
  * New test variants API
  * The LTP test library gained support for test variants, with that we can
    test family of similar syscalls (i.e. different select syscalls) in a
  * single test.
  * stime: Test 3 variants
  * sigpending: Test 3 variants
  * select04: Test 4 variants
  * ipsec: test also randomized message length
  * features: new checksum testcases
  * virt: add mode l3s in ipvlan test
  * netstress: support SO_REUSEPORT, MSG_ZEROCOPY
  * dhcp: correct prefix for expected IPv6 address)
  * lower down packet size to minimum, which still be high enough to require
  * fragmentation. This is critical for performance tests, which compare
  * virtual devices with the real ones.
  * netstress: various fixes to avoid false-positives
  * dhcp: AppArmor and SELinux fixes, fix paths for non-RHEL distros
* Fri Feb 22 2019 petr@cervinka.net
- Update to version 20190115
- Add rpmlintrc
- New tests
  * fanotify11 - test for FAN_REPORT_TID
  * fanotify01, fanotify03, fanotify10
  * added coverage for FAN_MARK_FILESYSTEM
  * fanotify03
  * added coverage for mountpoint mark
  * getrlimit03 - test if getrlimit syscalls return consistent data
  * increased coverage for readahead and posix_fadvise on overlayfs
  * execveat01 - functional tests
  * execveat02 - invalid inputs tests
  * statx06 - checks for correct statx timestamps
  * lremovexattr01 - functional tests
  * fremovexattr01 - functional tests
  * fremovexattr02 - invalid inputs tests
  * pt_test - Intel PT full trace test
  * membarier01 - functional tests
  * preadv201 - functional tests
  * preadv202 - invalid inputs tests
  * new open posix conformance tests for strchr, strcpy, strncpy,
- New regression tests
  * crypto_user01 aka CVE-2018-19854 (previously known as CVE-2013-2547)
  * fanout01 aka CVE-2017-15649
  * fanotify09
  * added coverage for merging events on child subdir
  * fixed in b469e7e47c8a "fanotify: fix handling of events on child sub-directory"
  * fanotify10 - test for mount ignore mask
  * fixed in 9bdda4e9cf2d fsnotify: fix ignore mask logic in fsnotify()
  * getxattr05
  * fixed in 82c9a927bc5d ("getxattr: use correct xattr length")
- Additional 37 tests were converted to the new test library; with that about
  30%% of the LTP syscall testcases have been converted so far
- The fzsync library intended to trigger kernel races has been rewritten again,
  the code is simpler now and at the same time the probability to hit races
  has increased.
* Fri Oct 27 2017 mpluskal@suse.com
- Update to version 20170929
* Sun Jul 16 2017 mpluskal@suse.com
- Update to version 20170516
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 20170116
* Tue Sep 20 2016 mpluskal@suse.com
- Update to version 20160920
* Fri Sep  2 2016 mpluskal@suse.com
- Add baselibs.conf
* Wed May 11 2016 mpluskal@suse.com
- Update to version 20160126
* Fri Mar 18 2016 mpluskal@suse.com
- Initial package for version 20160126
